using System;
using System.Diagnostics;
using Microsoft.Win32;

namespace MRJ.RecipeDB
{
/// <summary>
/// Summary description for Util.
/// </summary>
public class Util
{
   private static string strConnection = "";

   private Util()
   {
   }

   //-------------------------------------------------------------------------------
   // Purpose:
   //  This function reads the Connection String from the Registry.
   //
   // Parameters:
   //  none
   //
   // Returns:
   //  none
   //-------------------------------------------------------------------------------
   public static string GetConnectionString()
   {
      RegistryKey rkSoftware;
      RegistryKey rkMRJ;
      RegistryKey rkRecipe;
      RegistryKey rkVersion;

      // check if the Connect String has been read from the database.
      if (strConnection == "")
      {
         // Read string from Registry, store in static variable.
         rkSoftware = Registry.LocalMachine.OpenSubKey("SOFTWARE");
         if (rkSoftware == null)
            throw new Exception("Unable to open the SOFTWARE subky in the Registry.");

         rkMRJ = rkSoftware.OpenSubKey("MRJ");
         if (rkMRJ == null)
            throw new Exception("Unable to open the SOFTWARE\\MRJ subkey in the Registry.");

         rkRecipe = rkMRJ.OpenSubKey("Bug20084");
         if (rkRecipe == null)
            throw new Exception("Unable to open the SOFTWARE\\MRJ\\Bug20084 subkey in the Registry.");

         strConnection = rkRecipe.GetValue("ConnectionString").ToString();
      }

      return strConnection;
   }

   //-------------------------------------------------------------------------------
   // Purpose:
   //  This function logs errors to the Application's NT Event Log.
   //
   // Parameters:
   //  exc: the Exception object containing the error to Log.
   //
   // Returns:
   //  none
   //-------------------------------------------------------------------------------
   public static void LogError(Exception exc)
   {
      EventLog el;

      el = new EventLog("RecipeLog");
      el.Source = "RecipeDB";
      el.WriteEntry("Message:\r\n" + exc.Message + "\r\n\r\nStack Trace:\r\n" + exc.StackTrace, EventLogEntryType.Error);
   }
}
}
